==> zio-aws-computeoptimizer_2.13-5.17.190.1-sources.jar: zio/aws/computeoptimizer/model/RecommendationPreferencesDetail.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RecommendationPreferencesDetail(
    scope: Optional[zio.aws.computeoptimizer.model.Scope] = Optional.Absent,
    resourceType: Optional[zio.aws.computeoptimizer.model.ResourceType] =
      Optional.Absent,
    enhancedInfrastructureMetrics: Optional[
      zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics
    ] = Optional.Absent,
    inferredWorkloadTypes: Optional[
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail = {
    import RecommendationPreferencesDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
      .builder()
      .optionallyWith(scope.map(value => value.buildAwsValue()))(_.scope)
      .optionallyWith(resourceType.map(value => value.unwrap))(_.resourceType)
      .optionallyWith(enhancedInfrastructureMetrics.map(value => value.unwrap))(
        _.enhancedInfrastructureMetrics
      )
      .optionallyWith(inferredWorkloadTypes.map(value => value.unwrap))(
        _.inferredWorkloadTypes
      )
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.RecommendationPreferencesDetail.ReadOnly =
    zio.aws.computeoptimizer.model.RecommendationPreferencesDetail
      .wrap(buildAwsValue())
}
object RecommendationPreferencesDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.RecommendationPreferencesDetail =
      zio.aws.computeoptimizer.model.RecommendationPreferencesDetail(
        scope.map(value => value.asEditable),
        resourceType.map(value => value),
        enhancedInfrastructureMetrics.map(value => value),
        inferredWorkloadTypes.map(value => value)
      )
    def scope: Optional[zio.aws.computeoptimizer.model.Scope.ReadOnly]
    def resourceType: Optional[zio.aws.computeoptimizer.model.ResourceType]
    def enhancedInfrastructureMetrics
        : Optional[zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics]
    def inferredWorkloadTypes: Optional[
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ]
    def getScope
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.Scope.ReadOnly] =
      AwsError.unwrapOptionField("scope", scope)
    def getResourceType
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.ResourceType] =
      AwsError.unwrapOptionField("resourceType", resourceType)
    def getEnhancedInfrastructureMetrics: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics
    ] = AwsError.unwrapOptionField(
      "enhancedInfrastructureMetrics",
      enhancedInfrastructureMetrics
    )
    def getInferredWorkloadTypes: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ] =
      AwsError.unwrapOptionField("inferredWorkloadTypes", inferredWorkloadTypes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
  ) extends zio.aws.computeoptimizer.model.RecommendationPreferencesDetail.ReadOnly {
    override val scope
        : Optional[zio.aws.computeoptimizer.model.Scope.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scope())
        .map(value => zio.aws.computeoptimizer.model.Scope.wrap(value))
    override val resourceType
        : Optional[zio.aws.computeoptimizer.model.ResourceType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceType())
        .map(value => zio.aws.computeoptimizer.model.ResourceType.wrap(value))
    override val enhancedInfrastructureMetrics: Optional[
      zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.enhancedInfrastructureMetrics())
      .map(value =>
        zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics.wrap(value)
      )
    override val inferredWorkloadTypes: Optional[
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.inferredWorkloadTypes())
      .map(value =>
        zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
  ): zio.aws.computeoptimizer.model.RecommendationPreferencesDetail.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_2.13-5.19.31.2-sources.jar: zio/aws/computeoptimizer/model/RecommendationPreferencesDetail.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RecommendationPreferencesDetail(
    scope: Optional[zio.aws.computeoptimizer.model.Scope] = Optional.Absent,
    resourceType: Optional[zio.aws.computeoptimizer.model.ResourceType] =
      Optional.Absent,
    enhancedInfrastructureMetrics: Optional[
      zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics
    ] = Optional.Absent,
    inferredWorkloadTypes: Optional[
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ] = Optional.Absent,
    externalMetricsPreference: Optional[
      zio.aws.computeoptimizer.model.ExternalMetricsPreference
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail = {
    import RecommendationPreferencesDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
      .builder()
      .optionallyWith(scope.map(value => value.buildAwsValue()))(_.scope)
      .optionallyWith(resourceType.map(value => value.unwrap))(_.resourceType)
      .optionallyWith(enhancedInfrastructureMetrics.map(value => value.unwrap))(
        _.enhancedInfrastructureMetrics
      )
      .optionallyWith(inferredWorkloadTypes.map(value => value.unwrap))(
        _.inferredWorkloadTypes
      )
      .optionallyWith(
        externalMetricsPreference.map(value => value.buildAwsValue())
      )(_.externalMetricsPreference)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.RecommendationPreferencesDetail.ReadOnly =
    zio.aws.computeoptimizer.model.RecommendationPreferencesDetail
      .wrap(buildAwsValue())
}
object RecommendationPreferencesDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.RecommendationPreferencesDetail =
      zio.aws.computeoptimizer.model.RecommendationPreferencesDetail(
        scope.map(value => value.asEditable),
        resourceType.map(value => value),
        enhancedInfrastructureMetrics.map(value => value),
        inferredWorkloadTypes.map(value => value),
        externalMetricsPreference.map(value => value.asEditable)
      )
    def scope: Optional[zio.aws.computeoptimizer.model.Scope.ReadOnly]
    def resourceType: Optional[zio.aws.computeoptimizer.model.ResourceType]
    def enhancedInfrastructureMetrics
        : Optional[zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics]
    def inferredWorkloadTypes: Optional[
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ]
    def externalMetricsPreference: Optional[
      zio.aws.computeoptimizer.model.ExternalMetricsPreference.ReadOnly
    ]
    def getScope
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.Scope.ReadOnly] =
      AwsError.unwrapOptionField("scope", scope)
    def getResourceType
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.ResourceType] =
      AwsError.unwrapOptionField("resourceType", resourceType)
    def getEnhancedInfrastructureMetrics: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics
    ] = AwsError.unwrapOptionField(
      "enhancedInfrastructureMetrics",
      enhancedInfrastructureMetrics
    )
    def getInferredWorkloadTypes: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ] =
      AwsError.unwrapOptionField("inferredWorkloadTypes", inferredWorkloadTypes)
    def getExternalMetricsPreference: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.ExternalMetricsPreference.ReadOnly
    ] = AwsError.unwrapOptionField(
      "externalMetricsPreference",
      externalMetricsPreference
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
  ) extends zio.aws.computeoptimizer.model.RecommendationPreferencesDetail.ReadOnly {
    override val scope
        : Optional[zio.aws.computeoptimizer.model.Scope.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scope())
        .map(value => zio.aws.computeoptimizer.model.Scope.wrap(value))
    override val resourceType
        : Optional[zio.aws.computeoptimizer.model.ResourceType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceType())
        .map(value => zio.aws.computeoptimizer.model.ResourceType.wrap(value))
    override val enhancedInfrastructureMetrics: Optional[
      zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.enhancedInfrastructureMetrics())
      .map(value =>
        zio.aws.computeoptimizer.model.EnhancedInfrastructureMetrics.wrap(value)
      )
    override val inferredWorkloadTypes: Optional[
      zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.inferredWorkloadTypes())
      .map(value =>
        zio.aws.computeoptimizer.model.InferredWorkloadTypesPreference
          .wrap(value)
      )
    override val externalMetricsPreference: Optional[
      zio.aws.computeoptimizer.model.ExternalMetricsPreference.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.externalMetricsPreference())
      .map(value =>
        zio.aws.computeoptimizer.model.ExternalMetricsPreference.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.RecommendationPreferencesDetail
  ): zio.aws.computeoptimizer.model.RecommendationPreferencesDetail.ReadOnly =
    new Wrapper(impl)
}
